Class: Aws::SupportAuthZ::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SupportAuthZ::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-supportauthz/client.rb,
sig/client.rbs
Overview
An API client for SupportAuthZ. To construct a client, you need to configure a :region and :credentials.
client = Aws::SupportAuthZ::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSupportPermitResponseSuccess, _DeleteSupportPermitResponseSuccess, _GetActionResponseSuccess, _GetSupportPermitResponseSuccess, _ListActionsResponseSuccess, _ListSupportPermitRequestsResponseSuccess, _ListSupportPermitsResponseSuccess, _ListTagsForResourceResponseSuccess, _RejectSupportPermitRequestResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_support_permit(params = {}) ⇒ Types::CreateSupportPermitOutput
Creates a support permit that authorizes an AWS support operator to perform specified actions on specified resources.
-
#delete_support_permit(params = {}) ⇒ Types::DeleteSupportPermitOutput
Deletes a support permit, revoking the authorization previously granted to the AWS support operator.
-
#get_action(params = {}) ⇒ Types::GetActionOutput
Retrieves the description of a specific support action.
-
#get_support_permit(params = {}) ⇒ Types::GetSupportPermitOutput
Retrieves the details of a support permit by its ARN or name.
-
#list_actions(params = {}) ⇒ Types::ListActionsOutput
Lists available support actions for a specified AWS service.
-
#list_support_permit_requests(params = {}) ⇒ Types::ListSupportPermitRequestsOutput
Lists permit requests from AWS support operators.
-
#list_support_permits(params = {}) ⇒ Types::ListSupportPermitsOutput
Lists all support permits in the caller's account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a support permit resource.
-
#reject_support_permit_request(params = {}) ⇒ Types::RejectSupportPermitRequestOutput
Rejects a permit request from an AWS support operator.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for a support permit resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a support permit resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-supportauthz/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1020 1021 1022 |
# File 'lib/aws-sdk-supportauthz/client.rb', line 1020 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1023 1024 1025 |
# File 'lib/aws-sdk-supportauthz/client.rb', line 1023 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/aws-sdk-supportauthz/client.rb', line 993 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SupportAuthZ') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-supportauthz' context[:gem_version] = '1.0.0' Seahorse::Client::Request.new(handlers, context) end |
#create_support_permit(params = {}) ⇒ Types::CreateSupportPermitOutput
Creates a support permit that authorizes an AWS support operator to perform specified actions on specified resources. The permit is cryptographically signed using a customer-managed AWS KMS key (ECC_NIST_P384, SIGN_VERIFY) to ensure non-repudiation.
94 |
# File 'sig/client.rbs', line 94
def create_support_permit: (
|
#delete_support_permit(params = {}) ⇒ Types::DeleteSupportPermitOutput
Deletes a support permit, revoking the authorization previously granted to the AWS support operator.
136 |
# File 'sig/client.rbs', line 136
def delete_support_permit: (
|
#get_action(params = {}) ⇒ Types::GetActionOutput
Retrieves the description of a specific support action.
148 |
# File 'sig/client.rbs', line 148
def get_action: (
|
#get_support_permit(params = {}) ⇒ Types::GetSupportPermitOutput
Retrieves the details of a support permit by its ARN or name.
166 |
# File 'sig/client.rbs', line 166
def get_support_permit: (
|
#list_actions(params = {}) ⇒ Types::ListActionsOutput
Lists available support actions for a specified AWS service. Use pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
177 |
# File 'sig/client.rbs', line 177
def list_actions: (
|
#list_support_permit_requests(params = {}) ⇒ Types::ListSupportPermitRequestsOutput
Lists permit requests from AWS support operators. Use pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
190 |
# File 'sig/client.rbs', line 190
def list_support_permit_requests: (
|
#list_support_permits(params = {}) ⇒ Types::ListSupportPermitsOutput
Lists all support permits in the caller's account. Use pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
203 |
# File 'sig/client.rbs', line 203
def list_support_permits: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a support permit resource.
215 |
# File 'sig/client.rbs', line 215
def list_tags_for_resource: (
|
#reject_support_permit_request(params = {}) ⇒ Types::RejectSupportPermitRequestOutput
Rejects a permit request from an AWS support operator. The operator cannot proceed with the requested action.
225 |
# File 'sig/client.rbs', line 225
def reject_support_permit_request: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for a support permit resource.
234 |
# File 'sig/client.rbs', line 234
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a support permit resource.
244 |
# File 'sig/client.rbs', line 244
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1013 1014 1015 |
# File 'lib/aws-sdk-supportauthz/client.rb', line 1013 def waiter_names [] end |