Module: Aws::SupportAuthZ
- Defined in:
- lib/aws-sdk-supportauthz/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-supportauthz/plugins/endpoints.rb,
lib/aws-sdk-supportauthz/endpoint_provider.rb,
lib/aws-sdk-supportauthz/client_api.rb,
lib/aws-sdk-supportauthz/endpoints.rb,
lib/aws-sdk-supportauthz/resource.rb,
lib/aws-sdk-supportauthz/waiters.rb,
lib/aws-sdk-supportauthz/errors.rb,
lib/aws-sdk-supportauthz/client.rb,
lib/aws-sdk-supportauthz/types.rb,
lib/aws-sdk-supportauthz.rb
Overview
This module provides support for SupportAuthZ. This module is available in the
aws-sdk-supportauthz gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
support_auth_z = Aws::SupportAuthZ::Client.new
resp = support_auth_z.create_support_permit(params)
See Client for more information.
Errors
Errors returned from SupportAuthZ are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::SupportAuthZ::Errors::ServiceError
# rescues all SupportAuthZ API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.0.0'